use strict;
use warnings;
use Test::More 'no_plan';
use_ok('App::SmokeBrew');
use_ok('App::SmokeBrew::IniFile');
use_ok('App::SmokeBrew::Tools');
use_ok('App::SmokeBrew::Types');
use_ok('App::SmokeBrew::PerlVersion');
use_ok('App::SmokeBrew::BuildPerl');
use_ok('App::SmokeBrew::Plugin');
use_ok('App::SmokeBrew::Plugin::Null');
use_ok('App::SmokeBrew::Plugin::CPANPLUS::YACSmoke');
